@@ -382,7 +382,7 @@ static int init(CubicalFiltrationExt* self, PyObject* args, PyObject* kwds) {
                         &PyList_Type, &periodicity, &save_boundary_map))
     return -1;
 
-  if (!ArrayIsDoubleType(array))
+  if (!IsArrayTypeDouble(array))
     return -1;
 
   self->SetUp(array, periodicity, save_boundary_map);
