@@ -5,21 +5,12 @@
 #define NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION
 #include <numpy/arrayobject.h>
 
-#ifndef SIZEOF_PY_HASH_T
-typedef Py_ssize_t Py_hash_t;
-#endif
-
 template<class T> PyObject* cast_PyObj(T* obj) {
   return reinterpret_cast<PyObject*>(obj);
 }
 
-static bool ArrayIsDoubleType(PyArrayObject* points) {
-  if (PyArray_TYPE(points) == NPY_DOUBLE)
-    return true;
-
-  PyErr_SetString(PyExc_TypeError, "Array must be double");
-  return false;
-}
+bool homcloud_IsArrayTypeDouble(PyArrayObject* points);
+#define IsArrayTypeDouble homcloud_IsArrayTypeDouble
 
 template<typename T>
 T* GETPTR1D(PyArrayObject* ary, npy_intp i) {
