@@ -166,7 +166,7 @@ static int MergeTree_init(MergeTree* self,
                         &self->is_superlevel_, &self->is_lower_)) 
     return -1;
 
-  if (!ArrayIsDoubleType(bitmap))
+  if (!IsArrayTypeDouble(bitmap))
     return -1;
 
   self->ndim_ = PyArray_NDIM(bitmap);
