@@ -1,49 +1,19 @@
 import re
 import math
-import argparse
 
-import msgpack
-import numpy as np
-
-from homcloud.utils import parse_bool
-from homcloud.index_map import IndexMapForAbstractFiltration
+from homcloud.pdgm_format import PDGMWriter, BoundaryMapChunk
 import homcloud.phat_ext as phat
-from homcloud.filtration import Filtration, FiltrationWithIndex
-from homcloud.version import __version__
-from homcloud.license import add_argument_for_license
+from homcloud.argparse_common import parse_bool
 
 
-def main(args=None):
-    args = args or argument_parser().parse_args()
-    with open(args.input) as f:
-        filt = AbstractFiltrationWithIndex.load(f, args.save_boundary_map)
-    filt.compute_diagram_and_save(args.output)
-
-
-def argument_parser():
-    p = argparse.ArgumentParser(description="Convert a description of boundary map to a PD")
-    p.add_argument("-V", "--version", action="version", version=__version__)
-    p.add_argument("-M", "--save-boundary-map",
-                   default=True, type=parse_bool,
-                   help="save boundary map into idiagram file")
-    add_argument_for_license(p)
-    p.add_argument("input", help="input file name")
-    p.add_argument("output", help="output file name")
-    return p
-
-
-class AbstractFiltrationWithIndex(Filtration, FiltrationWithIndex):
-    def __init__(self, boundary_map, index_map, save_boundary_map):
+class AbstractFiltration:
+    def __init__(self, boundary_map, dim, levels, symbols, save_boundary_map):
         self.boundary_map = boundary_map
-        self.index_map = index_map
+        self.dim = dim
+        self.index_to_level = levels
+        self.index_to_symbol = symbols
         self.save_boundary_map = save_boundary_map
 
-    @staticmethod
-    def load(f, save_boundary_map):
-        loader = AbstractFiltrationLoader(f)
-        loader.load()
-        return loader.filtration(save_boundary_map)
-
     def build_phat_matrix(self):
         matrix = phat.Matrix(len(self.boundary_map), "none")
         for n, single in enumerate(self.boundary_map):
@@ -56,32 +26,27 @@ class AbstractFiltrationWithIndex(Filtration, FiltrationWithIndex):
 
         return matrix
 
-    def boundary_map_byte_sequence(self, *ignored):
-        if not self.save_boundary_map:
-            return None
-        packer = msgpack.Packer(use_bin_type=True, autoreset=False)
-        packer.pack_map_header(2)
-        packer.pack("type")
-        packer.pack("abstract")
-        packer.pack("map")
-        packer.pack_array_header(len(self.boundary_map))
-        for boundary in self.boundary_map:
-            packer.pack(boundary)
-        return packer.bytes()
+    def compute_pdgm(self, f, algorithm=None, output_suppl_info=True, parallels=None):
+        matrix = self.build_phat_matrix()
+        matrix.reduce(algorithm)
 
-    def write_indexed_complex(self, output):
-        raise(RuntimeError("Dipha is not supported by abstract filtration"))
+        writer = PDGMWriter(f, "abstract", self.dim)
+        writer.save_pairs(matrix.birth_death_pairs(), self.index_to_level, output_suppl_info)
+        if output_suppl_info:
+            writer.append_simple_chunk("index_to_level", self.index_to_level)
+            writer.append_simple_chunk("index_to_symbol", self.index_to_symbol)
 
-    @staticmethod
-    def favorite_algorithm():
-        return "phat-twist"
+        if self.save_boundary_map:
+            writer.append_chunk(BoundaryMapChunk("abstract", self.boundary_map))
+
+        writer.write()
 
 
 class ParseError(RuntimeError):
     pass
 
 
-class AbstractFiltrationLoader(object):
+class AbstractFiltrationLoader:
     def __init__(self, io):
         self.io = io
         self.autoid = False
@@ -90,6 +55,12 @@ class AbstractFiltrationLoader(object):
         self.lasttime = -math.inf
         self.boundary_information = []
 
+    @staticmethod
+    def load_from(f, save_boundary_map):
+        loader = AbstractFiltrationLoader(f)
+        loader.load()
+        return loader.filtration(save_boundary_map)
+
     def load(self):
         for line in self.io:
             line = line.strip()
@@ -106,15 +77,13 @@ class AbstractFiltrationLoader(object):
         levels = []
         boundary_map = []
         dims = []
-        for (id, symbol, dim, time, indices, coefs) in self.boundary_information:
+        for id, symbol, dim, time, indices, coefs in self.boundary_information:
             symbols.append(symbol)
             levels.append(time)
             dims.append(dim)
             boundary_map.append([dim, indices, coefs])
 
-        index_map = IndexMapForAbstractFiltration(np.array(levels, dtype=float),
-                                                  max(dims), symbols)
-        return AbstractFiltrationWithIndex(boundary_map, index_map, save_boundary_map)
+        return AbstractFiltration(boundary_map, max(dims), levels, symbols, save_boundary_map)
 
     OPTIONS = [re.compile(r"autoid\s*:"), re.compile(r"autosymbol\s*:")]
 
@@ -123,7 +92,7 @@ class AbstractFiltrationLoader(object):
 
     def parse_option(self, line):
         if self.boundary_information:
-            raise(ParseError("Options must be above boundary information"))
+            raise ParseError("Options must be above boundary information")
         command, _, args = line.lower().partition(":")
         args = args.strip()
         if command == "autoid":
@@ -138,19 +107,19 @@ class AbstractFiltrationLoader(object):
     def parse_line(self, line):
         def check_id(id):
             if id != self.nextid:
-                raise(ParseError("id must be incremental integers from 0"))
+                raise ParseError("id must be incremental integers from 0")
 
         def check_symbol(symbol):
             if not re.match(r"[a-zA-Z0-9_]+\Z", symbol):
-                raise(ParseError("Invalid cell symbol {}".format(symbol)))
+                raise ParseError("Invalid cell symbol {}".format(symbol))
 
         def check_time(time):
             if time < self.lasttime:
-                raise(ParseError("time must be monotone"))
+                raise ParseError("time must be monotone")
             self.lasttime = time
 
         if line.count("=") != 1:
-            raise(ParseError("\"=\" symbol is required"))
+            raise ParseError('"=" symbol is required')
 
         leftstr, rightstr = line.split("=")
 
@@ -165,7 +134,7 @@ class AbstractFiltrationLoader(object):
         time = float(left.pop(0))
         check_time(time)
         if left:
-            raise(ParseError("Too much elements in a line: \"{}\"".format(line)))
+            raise ParseError('Too much elements in a line: "{}"'.format(line))
 
         return id, symbol, dim, time, indices, coefs
 
@@ -177,10 +146,6 @@ class AbstractFiltrationLoader(object):
                 return []
 
         if s.count(":") != 1:
-            raise(ParseError("\":\" symbol is required"))
+            raise ParseError('":" symbol is required')
         indices_str, coef_str = re.split(r":", s.strip())
         return parse_numbers(indices_str), parse_numbers(coef_str)
-
-
-if __name__ == "__main__":
-    main()
