@@ -4,14 +4,15 @@ import numpy as np
 from cached_property import cached_property
 
 from homcloud.pict.utils import nd_indices
-from homcloud.base_filtration import Filtration
 from homcloud.cubical_ext import CubicalFiltrationExt
 from homcloud.pdgm_format import PDGMWriter, SimpleChunk, BitmapInformationChunk, BinaryChunk
 from homcloud.delegate import forwardable
+import homcloud.ph_routine as ph_routine
 
 
-class Bitmap(object):
+class Bitmap:
     def __init__(self, array, flip_levels_sign=False, periodicity=None, save_boundary_map=False):
+        assert array.size < 0x7FFF_FFFF
         self.array = array
         self.flip_levels_sign = flip_levels_sign
         self.periodicity = periodicity or [False] * array.ndim
@@ -41,7 +42,7 @@ class Bitmap(object):
         return -1 if self.flip_levels_sign else 1
 
 
-class BitmapFiltration(Filtration):
+class BitmapFiltration:
     def __init__(self, index_bitmap, periodicity, index_to_level, index_to_pixel, sign_flipped):
         self.index_bitmap = index_bitmap
         self.periodicity = periodicity
@@ -63,10 +64,10 @@ class BitmapFiltration(Filtration):
         for pixel in self.index_bitmap.flatten():
             f.write(struct.pack("d", pixel))
 
-    def compute_pdgm(self, f, algorithm=None, save_suppl_info=True):
+    def compute_pdgm(self, f, algorithm=None, save_suppl_info=True, parallels=1):
         writer = PDGMWriter(f, "bitmap", self.dim)
         writer.sign_flipped = self.sign_flipped
-        pairs, _ = self.compute_pairs(algorithm)
+        pairs, _ = ph_routine.find_ph_routine(self, algorithm).run(parallels=parallels)
         writer.save_pairs(pairs, self.index_to_level, save_suppl_info)
 
         if save_suppl_info:
@@ -75,11 +76,15 @@ class BitmapFiltration(Filtration):
             writer.append_chunk(BitmapInformationChunk(self.index_bitmap.shape, self.periodicity))
         writer.write()
 
-    def favorite_algorithm(self):
-        if self.index_bitmap.ndim in [2, 3]:
-            return "homccube-1"
+    @staticmethod
+    def supported_ph_routines():
+        return [ph_routine.HomcCube, ph_routine.Dipha]
+
+    def prefered_ph_routine(self):
+        if self.dim in [2, 3]:
+            return ph_routine.HomcCube(self, 1)
         else:
-            return "dipha"
+            return ph_routine.Dipha(self)
 
 
 def invert_permutation(a):
@@ -94,7 +99,7 @@ def invert_permutation(a):
 
 
 @forwardable
-class CubicalFiltration(Filtration):
+class CubicalFiltration:
     __delegator_definitions__ = {"cubefilt_ext": ["value_at", "encode_cube", "decode_cube", "all_cubes"]}
 
     def __init__(self, cubefilt_ext, sign_flipped):
@@ -132,19 +137,18 @@ class CubicalFiltration(Filtration):
     def write_dipha_complex(self, output):
         output.write(self.cubefilt_ext.dipha_byte_sequence())
 
-    @staticmethod
-    def favorite_algorithm():
-        return "phat-twist"
-
-    def compute_pdgm(self, f, algorithm=None, save_suppl_info=True):
+    def compute_pdgm(self, f, algorithm=None, save_suppl_info=True, parallels=None):
         writer = PDGMWriter(f, "cubical", self.dim)
-        pairs, boundary_map_byte_sequence = self.compute_pairs(algorithm)
-        writer.save_pairs(pairs, self.index_to_level, save_suppl_info)
+
+        matrix = self.build_phat_matrix()
+        matrix.reduce(algorithm)
+
+        writer.save_pairs(matrix.birth_death_pairs(), self.index_to_level, save_suppl_info)
 
         if save_suppl_info:
             writer.append_simple_chunk("index_to_level", self.index_to_level.tolist())
             writer.append_simple_chunk("index_to_cube", self.index_to_cube)
             writer.append_chunk(BitmapInformationChunk(self.shape, self.periodicity))
-        if boundary_map_byte_sequence:
+        if boundary_map_byte_sequence := matrix.boundary_map_byte_sequence():
             writer.append_chunk(BinaryChunk("boundary_map", boundary_map_byte_sequence))
         writer.write()
