@@ -67,7 +67,7 @@ class PHTrees:
         writer.append_chunk(filt.alpha_information_chunk())
         writer.append_chunk(SimpleChunk("index_to_level", filt.index_to_level))
         writer.append_chunk(SimpleChunk("vertex_symbols", filt.symbols))
-        writer.append_chunk(SimpleChunk("vertex_coordintes", filt.points.tolist()))
+        writer.append_chunk(SimpleChunk("vertex_coordintes", filt.coordinates.tolist()))
         writer.append_chunk(SimpleChunk("index_to_simplex", filt.index_to_simplex))
         writer.append_chunk(SimpleChunk("phtrees", self.to_list()))
         writer.write()
