@@ -6,6 +6,7 @@ import numpy as np
 
 from homcloud.cubical_ext import CubeEncoder
 from cached_property import cached_property
+from homcloud.alpha_filtration import boundary_of_simplex as boundary_of
 
 
 class GeometryResolverBase:
@@ -219,7 +220,7 @@ class RipsResolver:
         return [self.vertices[i] for i in path]
 
 
-class CoupledAlphaRelativeResolver:
+class PartialSimplicialResolver:
     def __init__(self, index_to_simplex, vertices):
         self.index_to_simplex = index_to_simplex
         self.vertices = vertices
@@ -238,15 +239,10 @@ class CoupledAlphaRelativeResolver:
         raise RuntimeError("boundary_cells is not supported")
 
     def boundary_simplices(self, cell_indices):
-        def cell_boundary(cell_index):
-            simplex = self.index_to_simplex[cell_index]
-            if len(simplex) == 1:
-                return []
-            return [tuple(simplex[:k] + simplex[k + 1 :]) for k in range(len(simplex))]
-
         ret = set()
         for cell_index in cell_indices:
-            for s in cell_boundary(cell_index):
+            for s in boundary_of(self.index_to_simplex[cell_index]):
+                s = tuple(s)
                 if s not in self.all_simplices:
                     continue
                 if s in ret:
@@ -256,6 +252,14 @@ class CoupledAlphaRelativeResolver:
 
         return ret
 
+    def resolve_vertices(self, cell_indices):
+        vertices = []
+        for cell_index in cell_indices:
+            for vertex in self.index_to_simplex[cell_index]:
+                vertices.append(vertex)
+
+        return [self.vertices[v] for v in set(vertices)]
+
     def resolve_boundary(self, cell_indices):
         boundary = self.boundary_simplices(cell_indices)
         return [[self.vertices[i] for i in s] for s in boundary]
