@@ -3,8 +3,9 @@
 This module provides the interface to HomCloud from python program.
 
 The API document is written by sphinx with Napolen.
-http://www.sphinx-doc.org/ja/stable/ext/napoleon.html
+https://www.sphinx-doc.org/en/master/usage/extensions/napoleon.html
 """
+
 from itertools import chain
 import subprocess
 from tempfile import TemporaryDirectory
@@ -13,27 +14,43 @@ from PIL import Image
 import numpy as np
 
 import homcloud.pict.utils as pict_utils
-import homcloud.view_index_pict as view_index_pict
+import homcloud.pict.show_birthdeath_pixels_2d
 import homcloud.pict.slice3d as pict_slice3d
 
 from homcloud.license import LICENSE_TERMS
 
 __all__ = [
     "LICENSE_TERMS",  # .homcloud.licence
-    "HomCloudError", "VolumeNotFound",  # .exceptions
-    "PDList", "PD", "Pair",  # .pd
-    "HistoSpec", "Mesh", "PIVectorizeSpec", "PIVectorizerMesh", "Histogram",
-    "MaskHistogram", "SliceHistogram",  # .histogram
-    "Volume", "OptimalVolume", "EigenVolume",
-    "StableVolume", "StableSubvolume",  # .optimal_volume
+    "HomCloudError",
+    "VolumeNotFound",  # .exceptions
+    "PDList",
+    "PD",
+    "Pair",  # .pd
+    "HistoSpec",
+    "Mesh",
+    "PIVectorizeSpec",
+    "PIVectorizerMesh",
+    "Histogram",
+    "MaskHistogram",
+    "SliceHistogram",  # .histogram
+    "VolumeFailure",
+    "Volume",
+    "OptimalVolume",
+    "EigenVolume",
+    "StableVolume",
+    "StableSubvolume",  # .optimal_volume
     "PHTrees",  # .phtrees
     "BitmapPHTrees",  # .bitmap_phtrees
     "distance_transform",  # .distance_transform
     "BitmapOptimal1Cycle",  # .bitmap_optimal_1_cycle
     "GraphOptimal1Cycle",  # .graph_optimal_1_cycle
     "Optimal1Cycle",  # .optimal_1_cycle
-    "example_data", "loadtxt_nd", "draw_volumes_on_2d_image",
-    "draw_birthdeath_pixels_2d", "show_slice3d",
+    "parallel_volume_computation",  # parallel_volume_computation
+    "example_data",
+    "loadtxt_nd",
+    "draw_volumes_on_2d_image",
+    "draw_birthdeath_pixels_2d",
+    "show_slice3d",
 ]
 from .exceptions import *
 from .pd import *
@@ -43,6 +60,7 @@ from .phtrees import *
 from .bitmap_phtrees import *
 from .bitmap_optimal_1_cycle import *
 from .distance_transform import *
+from .parallel_volume_computation import parallel_volume_computation
 from . import bitmap as bitmap
 from . import distance
 
@@ -64,48 +82,36 @@ def example_data(name):
                [ 4.,  2.,  6.]])
     """
     if name == "tetrahedron":
-        return np.array([
-            [0.0, 0.0, 0.0],
-            [8.0, 0.0, 0.0],
-            [5.0, 6.0, 0.0],
-            [4.0, 2.0, 6.0],
-        ])
+        return np.array(
+            [
+                [0.0, 0.0, 0.0],
+                [8.0, 0.0, 0.0],
+                [5.0, 6.0, 0.0],
+                [4.0, 2.0, 6.0],
+            ]
+        )
     if name == "bitmap_01_5x5x5":
-        return np.array([
-            [[0, 0, 1, 1, 1],
-             [0, 0, 0, 0, 1],
-             [0, 0, 0, 0, 1],
-             [0, 0, 0, 0, 1],
-             [0, 0, 0, 1, 1]],
-            [[0, 0, 1, 0, 0],
-             [0, 0, 0, 0, 0],
-             [0, 0, 0, 0, 0],
-             [0, 0, 0, 0, 0],
-             [0, 0, 1, 1, 0]],
-            [[0, 0, 1, 0, 0],
-             [0, 0, 0, 0, 0],
-             [0, 0, 0, 0, 0],
-             [0, 0, 0, 0, 0],
-             [0, 0, 1, 0, 0]],
-            [[0, 0, 1, 0, 0],
-             [0, 0, 0, 0, 0],
-             [0, 0, 0, 0, 0],
-             [0, 0, 0, 0, 0],
-             [0, 0, 1, 0, 0]],
-            [[1, 1, 1, 0, 0],
-             [1, 0, 0, 0, 0],
-             [1, 0, 0, 0, 0],
-             [1, 0, 0, 0, 0],
-             [1, 1, 1, 0, 0]]
-        ], dtype=bool)
+        return np.array(
+            [
+                [[0, 0, 1, 1, 1], [0, 0, 0, 0, 1], [0, 0, 0, 0, 1], [0, 0, 0, 0, 1], [0, 0, 0, 1, 1]],
+                [[0, 0, 1, 0, 0], [0, 0, 0, 0, 0], [0, 0, 0, 0, 0], [0, 0, 0, 0, 0], [0, 0, 1, 1, 0]],
+                [[0, 0, 1, 0, 0], [0, 0, 0, 0, 0], [0, 0, 0, 0, 0], [0, 0, 0, 0, 0], [0, 0, 1, 0, 0]],
+                [[0, 0, 1, 0, 0], [0, 0, 0, 0, 0], [0, 0, 0, 0, 0], [0, 0, 0, 0, 0], [0, 0, 1, 0, 0]],
+                [[1, 1, 1, 0, 0], [1, 0, 0, 0, 0], [1, 0, 0, 0, 0], [1, 0, 0, 0, 0], [1, 1, 1, 0, 0]],
+            ],
+            dtype=bool,
+        )
     if name == "bitmap_levels_5x5":
-        return np.array([
-            [0, 0, 1, 1, 1],
-            [0, 4, 0, 5, 1],
-            [0, 8, 0, 3, 1],
-            [0, 0, 4, 7, 1],
-            [0, 0, 2, 1, 1],
-        ], dtype=int)
+        return np.array(
+            [
+                [0, 0, 1, 1, 1],
+                [0, 4, 0, 5, 1],
+                [0, 8, 0, 3, 1],
+                [0, 0, 4, 7, 1],
+                [0, 0, 2, 1, 1],
+            ],
+            dtype=int,
+        )
 
     raise ValueError("Unknown example name: %s" % name)
 
@@ -142,17 +148,15 @@ def loadtxt_nd(path):
 
 
 def draw_pixels_on_2d_image(image, pixels, color, alpha=1.0):
-    for (y, x) in pixels:
+    for y, x in pixels:
         if x < 0 or y < 0 or x >= image.size[0] or y >= image.size[1]:
             continue
-        blended_color = tuple((np.array(image.getpixel((x, y))) * (1 - alpha) +
-                               np.array(color) * alpha).astype(int))
+        blended_color = tuple((np.array(image.getpixel((x, y))) * (1 - alpha) + np.array(color) * alpha).astype(int))
         image.putpixel((x, y), blended_color)
     return image
 
 
-def draw_volumes_on_2d_image(nodes, image, color, alpha=1.0,
-                             birth_position=None, death_position=None, marker_size=1):
+def draw_volumes_on_2d_image(nodes, image, color, alpha=1.0, birth_position=None, death_position=None, marker_size=1):
     """
     Draws optimal volumes for bitmap filtration on an image.
 
@@ -183,8 +187,7 @@ def draw_volumes_on_2d_image(nodes, image, color, alpha=1.0,
 
     def draw_marker(position, color):
         d = marker_size // 2
-        pixels = [(position[0] + dy, position[1] + dx)
-                  for dx in range(-d, d + 1) for dy in range(-d, d + 1)]
+        pixels = [(position[0] + dy, position[1] + dx) for dx in range(-d, d + 1) for dy in range(-d, d + 1)]
         draw_pixels_on_2d_image(image, pixels, color)
 
     pixels = set(chain.from_iterable([map(tuple, node.volume()) for node in nodes]))
@@ -201,10 +204,18 @@ def draw_volumes_on_2d_image(nodes, image, color, alpha=1.0,
 
 
 def draw_birthdeath_pixels_2d(
-        pairs, image, draw_birth=False, draw_death=False, draw_line=False,
-        scale=1, marker_type="filled-diamond", marker_size=1,
-        with_label=False, birth_color=(255, 0, 0), death_color=(0, 0, 255),
-        line_color=(0, 255, 0),
+    pairs,
+    image,
+    draw_birth=False,
+    draw_death=False,
+    draw_line=False,
+    scale=1,
+    marker_type="filled-diamond",
+    marker_size=1,
+    with_label=False,
+    birth_color=(255, 0, 0),
+    death_color=(0, 0, 255),
+    line_color=(0, 255, 0),
 ):
     """
     Draw birth/death pixels on the given image.
@@ -248,9 +259,7 @@ def draw_birthdeath_pixels_2d(
     """
     image = to_pil_image(image)
 
-    output_image, marker_drawer = view_index_pict.setup_images(
-        image, scale, not with_label
-    )
+    output_image, marker_drawer = homcloud.pict.show_birthdeath_pixels_2d.setup_images(image, scale, not with_label)
     marker_drawer.scale = scale
     marker_drawer.marker_size = marker_size
     marker_drawer.should_draw_birth_pixel = draw_birth
@@ -277,7 +286,7 @@ def to_pil_image(image):
     elif isinstance(image, Image.Image):
         return image
     else:
-        raise(RuntimeError("{} cannot be converted to PIL.Image".format(repr(image))))
+        raise RuntimeError("{} cannot be converted to PIL.Image".format(repr(image)))
 
 
 def show_slice3d(volumes, slice=0, spacer=0, range=None, image_viewer="eog -n"):
