@@ -6,15 +6,13 @@ def volume_range(volume):
 
 
 def volrange_to_slices(range):
-    return tuple(slice(b, e) for (b, e) in  zip(*range))
+    return tuple(slice(b, e) for (b, e) in zip(*range))
 
 
 def volume_to_bitmap(volume, range):
     min, max = range
     shape = max - min
-    indices = np.ravel_multi_index(
-        np.transpose(volume) - min[:, np.newaxis], shape
-    )
+    indices = np.ravel_multi_index(np.transpose(volume) - min[:, np.newaxis], shape)
     arr = np.zeros(shape=shape, dtype=bool)
     np.put(arr, indices, True)
     return arr
