@@ -1,23 +1,26 @@
 import numpy as np
 
 import homcloud.pict.tree as pict_tree
-import homcloud.paraview_interface as pv_interface
 import homcloud.plotly_3d as p3d
 from homcloud.spatial_searcher import SpatialSearcher
-from . import bitmap as bm
 
 
-class BitmapPHTrees(object):
+class BitmapPHTrees:
     """
     This class represents PH trees computed from a bitmap filtration.
 
     You can create an instance of this class by :meth:`PDList.bitmap_phtrees`.
 
+    Please see `Obayashi (2018) <https://doi.org/10.1137/17M1159439>`_ if you want to know
+    more about optimal volumes, and see `Obayashi (2023) <https://doi.org/10.1007/s41468-023-00119-8>`_
+    if you want to know more about stable volumes.
+
 
     Attributes:
         nodes (list of :class:`BitmapPHTrees.Node`): All nodes
         essential_nodes (list of :class:`BitmapPHTrees.Node`): All essential nodes
         nonessential_nodes (list of :class:`BitmapPHTrees.Node`): All nonessential nodes
+        roots (list of :class:`BitmapPHTrees.Node`): All root nodes
     """
 
     @staticmethod
@@ -35,25 +38,24 @@ class BitmapPHTrees(object):
             :class:`PDList`: The 0th and (n-1)st PDs with PH-trees.
         """
         from .pd import PDList
+
         is_superlevel = mode == "superlevel"
         lower, upper = pict_tree.construct_mergetrees(array, is_superlevel)
 
         f = PDList.open_pdgm_file(save_to)
         pict_tree.save_pdgm(f, array.ndim, is_superlevel, lower, upper)
         f.seek(0)
-        return PDList(f, PDList.FileType.PDGM)
+        return PDList(f)
 
     def __init__(self, treedict, is_superlevel):
         self.treedict = treedict
         self.is_superlevel = is_superlevel
 
-        self.nodes = [
-            self.node(id) for id in self.treedict["nodes"]
-            if not self.is_trivial_id(id)
-        ]
+        self.nodes = [self.node(id) for id in self.treedict["nodes"] if not self.is_trivial_id(id)]
         self.essential_nodes = [node for node in self.nodes if node.essential()]
         self.nonessential_nodes = [node for node in self.nodes if not node.essential()]
         self.spatial_searcher = self.build_spatial_searcher()
+        self.roots = [node for node in self.nodes if node.isroot()]
 
     def node(self, id):
         return BitmapPHTrees.Node(self, self.treedict["nodes"][id])
@@ -107,7 +109,40 @@ class BitmapPHTrees(object):
     def sign(self):
         return -1 if self.is_superlevel else 1
 
-    class Node(object):
+    class Volume:
+        """
+        This class is the superclass of :class:`Node` and :class:`StableVolume`.
+
+        This class defines common methods for these two classes.
+        """
+
+        def to_plotly3d_trace(self, color=None, name=""):
+            """
+            Constructs a plotly's trace object to visualize the volume
+
+            Args:
+                color (string or None): The name of the color
+                name (string): The name of the object
+
+            Returns:
+                plotly.graph_objects.Mesh3d: Plotly's trace object
+            """
+            return p3d.Voxels(self.volume(), color, name)
+
+        to_plotly3d = to_plotly3d_trace
+
+        def to_pyvista_mesh(self):
+            """
+            Constructs a PyVista's mesh object to visualize an optimal/stable volume
+
+            Returns:
+                pyvista.PolyData: PyVista's mesh object
+            """
+            import homcloud.pyvistahelper as pvhelper
+
+            return pvhelper.SparseVoxels(self.volume())
+
+    class Node(Volume):
         """
         This class represents a tree node of PH trees for a bitmap filtration.
 
@@ -187,7 +222,7 @@ class BitmapPHTrees(object):
 
         def stable_volume(self, epsilon):
             """
-            Returns the stable volume of the optimal volume.
+            Returns the stable volume of the optimal volume with parameter epsilon.
 
             Args:
                 epsilon (float): Duration noise strength
@@ -211,63 +246,29 @@ class BitmapPHTrees(object):
                 BitmapPHTrees.Node: The parent node of the node in the PH tree.
             """
             parent_id = self.dic["parent"]
-            return BitmapPHTrees.Node(self.mt,
-                                      self.mt.treedict["nodes"][parent_id])
+            return BitmapPHTrees.Node(self.mt, self.mt.treedict["nodes"][parent_id])
+
+        def isroot(self):
+            """
+            Returns:
+               bool: True if the node is a root node.
+            """
+            return self.dic["parent"] is None
 
         def children(self):
             """
             Returns:
                 list of :class:`BitmapPHTrees.Node`: All children nodes.
             """
-            return [
-                self.mt.node(child_id) for child_id in self.dic["children"]
-                if not self.mt.is_trivial_id(child_id)
-            ]
+            return [self.mt.node(child_id) for child_id in self.dic["children"] if not self.mt.is_trivial_id(child_id)]
 
         def __eq__(self, other):
-            return ((self.mt == other.mt) and
-                    (self.dic["id"] == other.dic["id"]))
+            return (self.mt == other.mt) and (self.dic["id"] == other.dic["id"])
 
         def __repr__(self):
             return "BitmapPHTrees.Node({}, {})".format(self.birth_time(), self.death_time())
 
-        def to_paraview_node(self, gui_name=None):
-            """
-            Construct a :class:`homcloud.paraview_interface.PipelineNode` object
-            to visulize :meth:`volume`.
-
-            You can show the volume by
-            :meth:`homcloud.paraview_interface.show`. You can also
-            adjust the visual by the methods of
-            :class:`homcloud.paraview_interface.PipelineNode`.
-
-            Args:
-                gui_name (string or None): The name shown in Pipeline Browser
-                    in paraview's GUI.
-
-            Returns:
-                homcloud.paraview_interface.PipelineNode: A PipelineNode object.
-            """
-            return BitmapPHTrees.to_paraview_node_from_nodes([self], gui_name)
-
-        to_pvnode = to_paraview_node
-
-        def to_plotly3d_trace(self, color=None, name=""):
-            """
-            Constructs a plotly's trace object to visualize the volume
-
-            Args:
-                color (string or None): The name of the color
-                name (string): The name of the object
-
-            Returns:
-                plotly.graph_objects.Mesh3d: Plotly's trace object
-            """
-            return p3d.Voxels(self.volume(), color, name)
-
-        to_plotly3d = to_plotly3d_trace
-
-    class StableVolume(object):
+    class StableVolume(Volume):
         """
         This class represents a stable volume in :class:`BitmapPHTrees`.
         """
@@ -298,68 +299,6 @@ class BitmapPHTrees(object):
             Returns the pixels of the stable volume.
 
             Returns:
-                set of tuple(int,...): The coordinates of all pixels.
+                list[tuple[int,...]]: The coordinates of all pixels.
             """
-            return self._volume
-
-        def to_paraview_node(self, gui_name=None):
-            """
-            Construct a :class:`homcloud.paraview_interface.PipelineNode` object
-            to visulize :meth:`volume`.
-
-            You can show the volume by
-            :meth:`homcloud.paraview_interface.show`. You can also
-            adjust the visual by the methods of
-            :class:`homcloud.paraview_interface.PipelineNode`.
-
-            Args:
-                gui_name (string or None): The name shown in Pipeline Browser
-                    in paraview's GUI.
-
-            Returns:
-                homcloud.paraview_interface.PipelineNode: A PipelineNode object.
-            """
-            return BitmapPHTrees.to_paraview_node_from_nodes([self], gui_name)
-
-        to_pvnode = to_paraview_node
-
-        def to_plotly3d_trace(self, color=None, name=""):
-            """
-            Constructs a plotly's trace object to visualize the stable volume
-
-            Args:
-                color (string or None): The name of the color
-                name (string): The name of the object
-
-            Returns:
-                plotly.graph_objects.Mesh3d: Plotly's trace object
-            """
-            return p3d.Voxels(list(self.volume()), color, name)
-
-        to_plotly3d = to_plotly3d_trace
-
-    @staticmethod
-    def to_paraview_node_from_nodes(nodes, gui_name=None):
-        """
-        Construct a :class:`homcloud.paraview_interface.PipelineNode`
-        object to visulize node volumes of the nodes.
-
-        Args:
-            nodes (list of :class:`BitmapPHTrees.Node`):
-                The list of nodes to be visualized.
-            gui_name (string or None): The name shown in Pipeline Browser
-                in paraview's GUI.
-
-        Returns:
-            homcloud.paraview_interface.VTK: Paraview Pipeline node object.
-        """
-        all_volume = []
-        for node in nodes:
-            all_volume.extend(node.volume())
-
-        min, max = bm.volume_range(all_volume)
-        bitmap = bm.volume_to_bitmap(all_volume, (min, max))
-
-        return pv_interface.VoxelData(bitmap, gui_name, min).threshold("value", (0.5, 1.0))
-
-    to_pvnode_from_nodes = to_paraview_node_from_nodes
+            return list(self._volume)
