@@ -1,9 +1,7 @@
-from homcloud.visualize_3d import ParaViewSparseCubeDrawer, ParaViewSimplexDrawer
-import homcloud.paraview_interface as pv_interface
 import homcloud.plotly_3d as p3d
 
 
-class Optimal1Cycle(object):
+class Optimal1Cycle:
     """The class represents an optimal (not volume-optimal) 1-cycle.
 
     This class is available only for alpha, cubical, rips, and abstract filtration
@@ -36,12 +34,12 @@ class Optimal1Cycle(object):
         """Birth position of the birth-death pair"""
         return self.pair.birth_position
 
-    def path(self):
+    def path(self, by="default"):
         """
         Returns:
             list of cell: All edges in the optimal 1-cycle.
         """
-        return self.geometry_resolver(False).resolve_cells(self.path_edges)
+        return self.get_geometry_resolver(by).resolve_cells(self.path_edges)
 
     def path_symbols(self):
         """
@@ -49,14 +47,14 @@ class Optimal1Cycle(object):
             list of ssimplex: All edges in the optimal 1-cycle
             in the form of the symbolic representation.
         """
-        return self.geometry_resolver(True).resolve_cells(self.path_edges)
+        return self.path("symbols")
 
-    def boundary_points(self):
+    def boundary_points(self, by="default"):
         """
         Returns:
             list of point: All vertices in the optimal 1-cycle.
         """
-        return self.geometry_resolver(False).resolve_vertices(self.path_edges)
+        return self.get_geometry_resolver(by).resolve_vertices(self.path_edges)
 
     def boundary_points_symbols(self):
         """
@@ -64,29 +62,10 @@ class Optimal1Cycle(object):
             list of string: All vertices in the optimal 1-cycle
             in the form of the symbolic representation.
         """
-        return self.geometry_resolver(True).resolve_vertices(self.path_edges)
+        return self.boundary_points("symbols")
 
-    def geometry_resolver(self, use_symbol):
-        return self.pair.diagram.pd.geometry_resolver(use_symbol)
-
-    def to_paraview_node(self, gui_name=None):
-        geom_resolver = self.geometry_resolver(False)
-
-        if self.pair.diagram.filtration_type == "cubical":
-            drawer = ParaViewSparseCubeDrawer(1, 3, {"isboundary": "1"})
-        elif self.pair.diagram.filtration_type == "alpha":
-            drawer = ParaViewSimplexDrawer(1, geom_resolver.vertices, {"isboundary": "1"})
-        else:
-            raise RuntimeError("Unsupported filtration type")
-
-        geom_resolver.draw_cells(drawer, self.path_edges, drawer.various_colors[0])
-
-        f = pv_interface.TempFile(".vtk")
-        drawer.write(f)
-        f.close()
-        return pv_interface.VTK(f.name, gui_name, f).set_representation("Wireframe")
-
-    to_pvnode = to_paraview_node
+    def get_geometry_resolver(self, by="default"):
+        return self.pair.diagram.get_geometry_resolver(by)
 
     def to_plotly3d_trace(self, color=None, width=1, name=""):
         """
