@@ -1,8 +1,7 @@
 import homcloud.pict.distance_transform as pict_distance_transform
 
 
-def distance_transform(pict, signed=False, metric="manhattan",
-                       periodicity=None, obstacle=None, VI=None, V=None):
+def distance_transform(pict, signed=False, metric="manhattan", periodicity=None, obstacle=None, VI=None, V=None):
     """Distance transform.
 
     Args:
