@@ -1,4 +1,4 @@
-class GraphOptimal1Cycle(object):
+class GraphOptimal1Cycle:
     """The class represents an optimal (not volume-optimal) 1-cycle computed from graph information.
 
     You can aquaire an optimal one cycle by :meth:`Pair.optimal_1_cycle`.
@@ -35,17 +35,20 @@ class GraphOptimal1Cycle(object):
         """
         return self.pair.death_time()
 
-    def boundary_points(self):
+    def boundary_points(self, by="vertex_indexes"):
         """Returns the points on the 1-cycle.
 
         Returns:
             list of int: The list of points on the cycle.
             Each point is represented by a number, which is assigned in 0-origin.
         """
-        return self.path_vertices
+        match by:
+            case "vertex_indexes" | "vindexes":
+                return self.path_vertices
+            case "symbols":
+                return self.pair.diagram.get_geometry_resolver("symbols").resolve_graph_path(self.path_vertices)
+            case _:
+                raise ValueError(f"Unknown by: {by}")
 
     def boundary_points_symbols(self):
-        return self.geometry_resolver(False).resolve_graph_path(self.path_vertices)
-
-    def geometry_resolver(self, use_symbol):
-        return self.pair.diagram.pd.geometry_resolver(use_symbol)
+        return self.boundary_points("symbols")
