@@ -15,6 +15,7 @@ import homcloud.bitmap
 import homcloud.abstract_filtration as abstract_filtration
 import homcloud.simplicial_levelset as simplicial_levelset
 import homcloud.coupled_alpha as coupled_alpha
+import homcloud.alpha_voronoi_relative_mask as alpha_voronoi_relative_mask
 import homcloud.optvol as optvol
 import homcloud.int_reduction as int_reduction
 import homcloud.pdgm as pdgm
@@ -126,35 +127,9 @@ class PDList:
                 not squared.
             no_squared (bool): See `squared` parameter.
             subsets (list[int] or bool or None):
-                This parameter is used to introduce equivalence relationship.
-
-                This parameter allows you to analyze the interspace structures
-                between two or more objects in your pointcloud.
-
-                If the grouped sub-pointcloud constructs a contractible subcomplex,
-                the relative homology is comptuted.
-                If the grouped sub-pointcloud constructs a subcomplexes whose connected components
-                are contractible, each connected component in the subcomplexes
-                is shrinked into a single point and
-                birth-death pairs corresponding to the connected components are removed from the 0th PD.
-                In the homcloud's code, minus infinity is assigned to the levels of
-                all simplices in the subcomplex and PDs are comptuted, and all birth-death pairs whose
-                birth time is -inf are removed from the diagrams.
-
-                If `subsets` is None, normal persistent homology is computed.
-
-                If `subsets` is a list of integers whose length is the same
-                as the number of points, the points are grouped
-                by the integers and the gaps in the points in the same
-                group is filled. The integer -1 in this list means
-                that the point does not belong to any group.
-
-                If subsets is True, the last column of `pointcloud` is regarded
-                as the list of group id.
+                This parameter is currently unused.
             check_acyclicity (bool):
-                Checks the acyclicity of each grouped points in subsets
-                if True. This parameter is used only if `subsets` parameter
-                is used.
+                This parameter is currently unused.
             algorithm (string or None): The name of the algorithm.
                 An appropriate algorithm is
                 automatically selected if None is given.
@@ -216,6 +191,8 @@ class PDList:
         """
         assert indexed
         assert (save_phtrees and save_boundary_map) or (not save_phtrees)
+        assert subsets is False
+        assert check_acyclicity is False
 
         def is_squared():
             match (squared, no_squared):
@@ -233,24 +210,15 @@ class PDList:
 
         pointcloud = pointcloud.astype(float)
         num_points = pointcloud.shape[0]
-        dim = pointcloud.shape[1] - int(weight is True) - int(subsets is True)
+        dim = pointcloud.shape[1] - int(weight is True)
 
         if isinstance(weight, np.ndarray):
             pointcloud = np.hstack([pointcloud, weight.reshape(num_points, 1)])
             weight = True
 
-        if isinstance(subsets, np.ndarray):
-            pointcloud = np.hstack([pointcloud, subsets.reshape(num_points, 1)])
-            subsets = True
-
-        alpha_shape = alpha_filtration.AlphaShape.build(pointcloud, dim, weight, subsets, periodicity)
-
-        if check_acyclicity:
-            alpha_shape.check_subsets_acyclicity()
-        if subsets:
-            alpha_shape.become_partial_shape()
-
-        filtration = alpha_shape.create_filtration(squared, vertex_symbols, save_boundary_map, save_phtrees)
+        filtration = alpha_filtration.AlphaFiltration.create(
+            pointcloud, dim, weight, periodicity, squared, vertex_symbols, save_boundary_map, save_phtrees
+        )
 
         return PDList.compute_pd(filtration, save_to, parallels, algorithm, save_suppl_info)
 
@@ -682,6 +650,99 @@ class PDList:
         filtration = coupled_alpha_shape.relative_ph_filtration(squared, symbols, save_boundary_map)
         return PDList.compute_pd(filtration, save_to, 1, algorithm, save_suppl_info)
 
+    @staticmethod
+    def from_alpha_voronoi_relative_mask_filtration(
+        pc_main,
+        pc_mask,
+        *,
+        squared=True,
+        weighted=False,
+        weight_main=None,
+        weight_mask=None,
+        algorithm=None,
+        vertex_symbols=None,
+        save_to=None,
+        save_suppl_info=True,
+        save_boundary_map=False,
+        periodicity=None,
+    ):
+        """
+        Compute persistence diagrams from (weighted) alpha filtration with a mask constructed
+        by voronoi cells using relative persistent homology.
+
+        Normal PH for alpha filtration considers the homology of the growing balls
+        $H_*(\\cup_{x} B_x(r))$.
+        This method alternatively considers
+        $H_*((\\cup_{x \\in P} B_x(r)) \\cup M, M)$,
+        where $P$ is `pc_main`, $Q$ is `pc_mask`,
+        $\\{V_{x}\\}_{x \\in P \\cup Q}$ is the voronoi cells of $P \\cup Q$,
+        and $M = \\cup_{q \\in Q} V_q$.
+
+        Args:
+            pc_main (numpy.ndarray): Point cloud data. Each row
+                represents a single point.
+                Only 2D or 3D pointclouds are available.
+            pc_mask (numpy.ndarray): Point cloud data for mask. 
+                Each row represents a single point.
+                The dimension should be the same sa pc_main.
+            squared (bool): By default, all birth/death times are squared.
+                If squared is False, all computed birth/death times are
+                not squared.
+            weighted (bool): If False, the pointcloud has no weight. If True,
+                the last column of the pointcloud ndarray is regarded as
+                weights. Please note that the weight paramters of points
+                should be the square of their own radii.
+            weight_main (numpy.ndarray | None): Weights for pc_main.
+            weight_mask (numpy.ndarray | None): Weights for pc_mask.
+            algorithm (string or None): The name of the algorithm.
+                An appropriate algorithm is
+                automatically selected if None is given.
+
+                The following algorithms are available:
+
+                * "phat-twist"
+                * "phat-chunk-parallel"
+
+                In many cases, the parameter should be `None`.
+            vertex_symbols (list[string] or None): The names of vertices.
+                The names are used to represent some simplices, such as
+                birth/death simplices or optimal volumes.
+
+                If None is given, vertices are automatically named by
+                "0", "1", "2", ...
+            save_to (string): The file path which the computation result is
+                saved into. You can load the saved data by
+                ``homcloud.interface.PDList(FILE_PATH)``.
+                Saving the result is recommended since the computation cost is
+                often expensive.
+            save_suppl_info (bool): Various supplimentary information is saved to
+                the file `save_to`. The default is True. This information is
+                required to show birth and death pixels and optimal volumes.
+                If you do not use such HomCloud's functionality and you want to
+                reduce the size of the file, please set the argument ``False``.
+                If False, only birth and death times are stored to the file.
+            save_boundary_map (bool):
+                The boundary map constructed by the given pointcloud is saved
+                if this parameter is True. The boundary map is used to
+                compute volume optimal cycles.
+            periodicity (tuple[tuple[float, float], tuple[float, float]], tuple[tuple[float, float], tuple[float, float], tuple[float, float]] or None):  # noqa E501
+                Periodic boundary condition. Peridic boundary condition is not available for 2D alpha shape.
+        Returns:
+            The :class:`PDList` object computed from the pointcloud.
+
+
+        """
+        if weight_main is not None:
+            weighted = True
+            pc_main = np.hstack([pc_main, weight_main.reshape(-1, 1)])
+            pc_mask = np.hstack([pc_mask, weight_mask.reshape(-1, 1)])
+        dim = pc_main.shape[1] - int(weighted)
+
+        filtration = alpha_voronoi_relative_mask.AlphaVoronoiRelativeMaskFiltration.create(
+            pc_main, pc_mask, dim, weighted, periodicity, squared, vertex_symbols, save_boundary_map
+        )
+        return PDList.compute_pd(filtration, save_to, 1, algorithm, save_suppl_info)
+
     def save(self, dest):
         """Save the PDList into `dest`.
 
