@@ -1,13 +1,17 @@
+import numpy as np
+
 import homcloud.phtrees as phtrees
-import homcloud.paraview_interface as pv_interface
+import homcloud.plotly_3d as p3d
 from homcloud.spatial_searcher import SpatialSearcher
 
-class PHTrees(object):
+
+class PHTrees:
     """
     This class represents PH trees computed from an alpha filtration.
 
-    Please see `<https://arxiv.org/abs/1712.05103>`_ if you want to know
-    the details of optimal volumes and volume optimal cycles.
+    Please see `Obayashi (2018) <https://doi.org/10.1137/17M1159439>`_ if you want to know
+    more about optimal volumes, and see `Obayashi (2023) <https://doi.org/10.1007/s41468-023-00119-8>`_
+    if you want to know more about stable volumes.
 
     You can compute the PH trees by :meth:`PDList.from_alpha_filtration`
     with ``save_boundary_map=True`` and ``save_phtrees=True`` arguments.
@@ -49,19 +53,32 @@ class PHTrees(object):
             SpatialSearcher(pdgm.death_indices, pdgm.births, pdgm.deaths),
         )
 
+    @property
+    def all_nodes(self):
+        """
+        Return all nodes.
+
+        Returns:
+            list[:class:`PHTrees.Node`]: The nodes.
+        """
+        return list(self.orig.nodes.values())
+
+    @property
+    def roots(self):
+        return self.orig.roots
+
     def nodes_of(self, pairs):
         """
         Returns the nodes of trees corresponding to birth-death pairs
         in `pairs`.
 
         Args:
-            pairs (list of Pair): The list of pairs.
+            pairs (list[Pair]): The list of pairs.
 
         Returns:
-            list of :class:`PHTrees.Node`: The nodes.
+            list[:class:`PHTrees.Node`]: The nodes.
         """
-        return [self._resolver().phtree.nodes[pair.death_index]
-                for pair in pairs]
+        return [self._resolver().phtree.nodes[pair.death_index] for pair in pairs]
 
     def pair_node_nearest_to(self, x, y):
         """
@@ -73,7 +90,7 @@ class PHTrees(object):
             y (float): The death-axis coordinate.
 
         Returns:
-            PHTrees.Node: The nearest node.
+            :class:`PHTrees.Node`: The nearest node.
 
         """
         return self.orig.nodes[self.spatial_searcher.nearest_pair(x, y)]
@@ -90,41 +107,14 @@ class PHTrees(object):
            ymax (float): The maximum of the death-axis of the rectangle.
 
         Returns:
-           list of :class:`PHTrees.Node`: The nodes in the rectangle.
+           list[:class:`PHTrees.Node`]: The nodes in the rectangle.
 
         """
         return [
-            self.orig.nodes[death_index] for death_index
-            in self.spatial_searcher.in_rectangle(xmin, xmax, ymin, ymax)
+            self.orig.nodes[death_index] for death_index in self.spatial_searcher.in_rectangle(xmin, xmax, ymin, ymax)
         ]
 
-    def to_paraview_node_from_nodes(self, nodes, gui_name=None):
-        """
-        Construct a :class:`homcloud.paraview_interface.PipelineNode`
-        object to visulize optimal volumes of the nodes.
-
-        Args:
-            nodes (list of :class:`PHTrees.Node`): The list of nodes to be visualized.
-            gui_name (string or None): The name shown in Pipeline Browser
-                in paraview's GUI.
-
-        Returns:
-            homcloud.paraview_interface.VTK: Paraview Pipeline node object.
-
-        Notes:
-            All nodes should be nodes of `self` PHTrees.
-        """
-        f = pv_interface.TempFile(".vtk")
-        drawer = self.orig.coord_resolver.build_paraview_drawer(len(nodes), {})
-        for i, node in enumerate(nodes):
-            node.draw_volume(drawer, i)
-        drawer.write(f)
-        f.close()
-        return pv_interface.VTK(f.name, gui_name, f).set_representation("Wireframe")
-
-    to_pvnode_from_nodes = to_paraview_node_from_nodes
-
-    class Volume(object):
+    class Volume:
         """
         The superclass of :class:`PHTrees.Node` and :class:`PHTrees.StableVolume`.
 
@@ -143,12 +133,12 @@ class PHTrees(object):
 
             simplices()
                 Returns:
-                    list of list of list of float, a.k.a list of simplex:
+                    list[list[list[float]]], a.k.a list[Simplex]:
                         The simplices in the optimal volume.
 
             boundary()
                 Returns:
-                    list of list of float, a.k.a. list of points:
+                    list[list[float]], a.k.a. list[Point]:
                         Points in the volume optimal cycle.
 
             birth_simplex()
@@ -159,14 +149,14 @@ class PHTrees(object):
 
             ancestors()
                 Returns:
-                    list of :class:`PHTrees.Node`:
+                    list[:class:`PHTrees.Node`]:
                         The ancestors of the tree node include itself.
         """
 
         def points(self):
             """
             Returns:
-                list of list of float, a.k.a list of points:
+                list[list[float]], a.k.a list[Point]:
                     Points in the optimal volume.
             """
             return self.vertices()
@@ -177,15 +167,14 @@ class PHTrees(object):
         def boundary_points(self):
             """
             Returns:
-                list of list of float, a.k.a list of points:
-                    Points in the volume optimal cycle.
+                list[list[float]]: All vertices in the boundary of the optimal/stable volume
             """
             return self.boundary_vertices()
 
         def points_symbols(self):
             """
             Returns:
-                list of string: All vertices in the optimal volume
+                list[str]: All vertices in the optimal/stable volume
                 in the form of the symbolic representation.
             """
             return self.vertices("symbols")
@@ -193,7 +182,7 @@ class PHTrees(object):
         def volume_simplices_symbols(self):
             """
             Returns:
-                list of list of string: All simplices in volume optimal cycles
+                list[list[str]]: All simplices in optimal/stable volume
                 in the form of the symbolic representation.
             """
             return self.simplices("symbols")
@@ -201,7 +190,7 @@ class PHTrees(object):
         def boundary_points_symbols(self):
             """
             Returns:
-                list of string: All vertices in the volume optimal cycle
+                list[str]: All vertices in the boundary of the optimal/stable volume
                 in the form of the symbolic representation.
             """
             return self.boundary_vertices("symbols")
@@ -209,7 +198,7 @@ class PHTrees(object):
         def boundary_symbols(self):
             """
             Returns:
-                list of list of string: All simplices in the volume optimal cycle
+                list[list[str]]: All simplices in the optimal/stable volume
                 in the form of the symbolic representation.
             """
             return self.boundary("symbols")
@@ -222,29 +211,49 @@ class PHTrees(object):
             """
             return self.birth_time() != self.death_time()
 
-        def to_paraview_node(self, gui_name=None):
+        def to_plotly3d_trace(self, color="green", width=1, name=""):
             """
-            Construct a :class:`homcloud.paraview_interface.PipelineNode`
-            object to visulize an optimal volume of the node.
+            Constructs a plotly's trace object to visualize the optimal volume
 
-            gui_name (string or None): The name shown in Pipeline Browser
-                in paraview's GUI.
+            Args:
+                color (str | None): The name of the color
+                width (int): The width of the line
+                name (str): The name of the object
 
             Returns:
-                homcloud.paraview_interface.VTK: Paraview Pipeline node object.
+                plotly.graph_objects.Scatter3d: Plotly's trace object
             """
-            f = pv_interface.TempFile(".vtk")
-            drawer = self.trees.coord_resolver.build_paraview_drawer(1, {})
-            self.draw_volume(drawer, 0)
-            drawer.write(f)
-            f.close()
-            return pv_interface.VTK(f.name, gui_name, f).set_representation("Wireframe")
+            return p3d.Simplices(self.boundary(), color, width, name)
 
-        to_pvnode = to_paraview_node
+        to_plotly3d = to_plotly3d_trace
+
+        def to_plotly3d_mesh(self, color="green", name=""):
+            """
+            Constructs a plotly's trace object to visualize the face of an optimal/stable volume
+
+            Args:
+                color (str | None): The name of the color
+                name (str): The name of the object
+
+            Returns:
+                plotly.graph_objects.Mesh3d: Plotly's trace object
+            """
+            return p3d.SimplicesMesh(self.boundary(), color, name)
+
+        def to_pyvista_mesh(self):
+            """
+            Constructs a PyVista's mesh object to visualize the face of an optimal/stable volume
+
+            Returns:
+                pyvista.PolyData: PyVista's mesh object
+            """
+            import homcloud.pyvistahelper as pvhelper
+
+            return pvhelper.Triangles(self.boundary())
 
     class Node(Volume, phtrees.Node):
         """
-        The class represents a tree node of :class:`PHTrees`.
+        The class represents a tree node of :class:`PHTrees`. A node have information about an optimal volume.
         """
 
         def ancestors(self):
@@ -258,10 +267,16 @@ class PHTrees(object):
             return ret
 
         def living_descendants(self):
+            """
+            Returns:
+                list[:class:`PHTrees.Node`]: All descendant nodes with positive lifetime
+            """
             return [node for node in self.volume_nodes if node.living()]
 
         def stable_volume(self, epsilon):
             """
+            Returns the stable volume corresponding to self.
+
             Args:
                 epsilon (float): Duration noise strength
 
@@ -271,12 +286,17 @@ class PHTrees(object):
             """
             return super().stable_volume(epsilon, PHTrees.StableVolume)
 
+        def stable_volume_information(self):
+            thresholds = np.array([child.birth_time() - self.birth_time() for child in self.children])
+            volumes = np.array([child.volume_size() for child in self.children])
+            return (thresholds, volumes)
+
         def __repr__(self):
-            return "PHTrees.Node({}, {})".format(self.birth_time(),
-                                                 self.death_time())
+            return "PHTrees.Node({}, {})".format(self.birth_time(), self.death_time())
 
     class StableVolume(Volume, phtrees.StableVolume):
         """
         The class represents a stable volume in :class:`PHTrees`.
         """
+
         pass
