@@ -182,6 +182,12 @@ class PDGM(PDGMBase):
             return self.pdgmreader.load_chunk("alpha_information")["num_vertices"]
         if self.filtration_type == "rips":
             return self.pdgmreader.load_chunk("rips_information")["num_vertices"]
+        if self.filtration_type == "coupled-alpha-relative":
+            info = self.pdgmreader.load_chunk("coupled_alpha_relative_information")
+            return info["num_vertices_X"] + info["num_vertices_Y"]
+        if self.filtration_type == "alpha-voronoi-relative-mask":
+            info = self.pdgmreader.load_chunk("alpha_voronoi_relative_mask_information")
+            return info["num_vertices_main"] + info["num_vertices_mask"]
 
     @cached_property
     def simplicial_symbol_resolver(self):
@@ -260,28 +266,28 @@ class PDGM(PDGMBase):
         )
 
     @cached_property
-    def coupled_alpha_relative_coord_resolver(self):
-        assert self.filtration_type == "coupled-alpha-relative"
+    def partial_simplicial_coord_resolver(self):
+        assert self.filtration_type in ["coupled-alpha-relative", "alpha-voronoi-relative-mask"]
 
-        return geom_resolver.CoupledAlphaRelativeResolver(
+        return geom_resolver.PartialSimplicialResolver(
             self.pdgmreader.load_simple_chunk("index_to_simplex"),
             self.pdgmreader.load_simple_chunk("vertex_coordintes"),
         )
 
     @cached_property
-    def coupled_alpha_relative_symbol_resolver(self):
-        assert self.filtration_type == "coupled-alpha-relative"
+    def partial_simplicial_symbol_resolver(self):
+        assert self.filtration_type in ["coupled-alpha-relative", "alpha-voronoi-relative-mask"]
 
-        return geom_resolver.CoupledAlphaRelativeResolver(
+        return geom_resolver.PartialSimplicialResolver(
             self.pdgmreader.load_simple_chunk("index_to_simplex"),
             self.pdgmreader.load_simple_chunk("vertex_symbols") or self.default_vertex_symbols(),
         )
 
     @cached_property
-    def coupled_alpha_relative_vertex_index_resolver(self):
-        assert self.filtration_type == "coupled-alpha-relative"
+    def partial_simplicial_vertex_index_resolver(self):
+        assert self.filtration_type in ["coupled-alpha-relative", "alpha-voronoi-relative-mask"]
 
-        return geom_resolver.CoupledAlphaRelativeResolver(
+        return geom_resolver.PartialSimplicialResolver(
             self.pdgmreader.load_simple_chunk("index_to_simplex"),
             list(range(self.num_vertices)),
         )
@@ -306,12 +312,12 @@ class PDGM(PDGMBase):
                 return self.abstract_geometry_resolver
             case ("rips", "default" | "symbols"):
                 return self.rips_geometry_resolver
-            case ("coupled-alpha-relative", "default" | "coordinates"):
-                return self.coupled_alpha_relative_coord_resolver
-            case ("coupled-alpha-relative", "symbols"):
-                return self.coupled_alpha_relative_symbol_resolver
-            case ("coupled-alpha-relative", "vertex_indexes" | "vindexes"):
-                return self.coupled_alpha_relative_vertex_index_resolver
+            case ("coupled-alpha-relative" | "alpha-voronoi-relative-mask", "default" | "coordinates"):
+                return self.partial_simplicial_coord_resolver
+            case ("coupled-alpha-relative" | "alpha-voronoi-relative-mask", "symbols"):
+                return self.partial_simplicial_symbol_resolver
+            case ("coupled-alpha-relative" | "alpha-voronoi-relative-mask", "vertex_indexes" | "vindexes"):
+                return self.partial_simplicial_vertex_index_resolver
             case _:
                 raise RuntimeError(f"Geometry resolver is unavailable for {self.filtration_type}, {resolver_type}")
 
