@@ -162,6 +162,31 @@ class CoupledAlphaRelativeInformationChunk:
         return {"chunktype": "coupled_alpha_relative_information", "start": start, "length": len(self.binary)}
 
 
+class AlphaVoronoiRelativeMaskInformationChunk:
+    def __init__(self, num_vertices_main, num_vertices_mask, periodicity, weighted, squared):
+        self.num_vertices_main = num_vertices_main
+        self.num_vertices_mask = num_vertices_mask
+        self.periodicity = periodicity
+        self.weighted = weighted
+        self.squared = squared
+
+    @cached_property
+    def binary(self):
+        return msgpack.packb(
+            {
+                "chunktype": "alpha_voronoi_relative_mask_information",
+                "num_vertices_main": self.num_vertices_main,
+                "num_vertices_mask": self.num_vertices_mask,
+                "periodicity": self.periodicity,
+                "weighted": self.weighted,
+                "squared": self.squared,
+            }
+        )
+
+    def metadata(self, start):
+        return {"chunktype": "alpha_voronoi_relative_mask_information", "start": start, "length": len(self.binary)}
+
+
 class BoundaryMapChunk:
     def __init__(self, type, map):
         self.type = type
