@@ -48,18 +48,16 @@ def read_nd_picture_text(f):
 
 
 def stack_picts(picts):
-    """Stacking pictures into one ndarray
-    """
+    """Stacking pictures into one ndarray"""
     if not all([pict.shape == picts[0].shape for pict in picts]):
         raise RuntimeError("Sizes of all pictures should be same")
     return np.array(picts)
 
 
 def load_picture(path, filetype="picture"):
-    """Load a picture and return 2D ndarray whose values are less than 256.
-    """
+    """Load a picture and return 2D ndarray whose values are less than 256."""
     if filetype == "picture":
-        pict = imageio.imread(path, as_gray=True)
+        pict = imageio.v3.imread(path, mode="L")
         if np.max(pict) > 255:
             pict //= 256
         return pict
@@ -79,8 +77,7 @@ def nd_indices(shape):
     return np.indices(shape).reshape(len(shape), n).transpose()
 
 
-def build_levelset_filtration(pict, cubical, periodic, superlevel,
-                              save_boundary_map):
+def build_levelset_filtration(pict, cubical, periodic, superlevel, save_boundary_map):
     from homcloud.bitmap import Bitmap
 
     if cubical or periodic or save_boundary_map:
