@@ -92,7 +92,7 @@ class TestPHTrees:
         filt.periodicity = None
         filt.index_to_level = [0, 0, 0, 0, 0, 0, 0, 1, 2, 2, 3]
         filt.symbols = ["a", "b", "c", "d"]
-        filt.points = np.array([[0, 0], [0.5, 1], [0, 2], [-0.5, 1]])
+        filt.coordinates = np.array([[0, 0], [0.5, 1], [0, 2], [-0.5, 1]])
         filt.index_to_simplex = [[0], [1, 2]]
         filt.points_weighted = False
         filt.alpha_information_chunk.return_value = AlphaInformationChunk(4, None, False, True)
