@@ -1,13 +1,12 @@
-# pylint: disable=C0103,C0111,W0201,R0201,R0903
 import os
 
 import pytest
 
-import homcloud.dump_diagram as dump_diagram
+import homcloud.cli.dump_diagram as dump_diagram
 
 
 @pytest.mark.integration
-class Test_main(object):
+class Test_main:
     def test_case_pdgm(self, datadir):
         path = os.path.join(datadir, "tetrahedron.pdgm")
         dump_diagram.main(dump_diagram.argument_parser().parse_args(["-d", "1", "-o", os.devnull, "-S", "off", path]))
