@@ -7,7 +7,7 @@ from homcloud.geometry_resolver import (
     PeriodicSimplicialResolver,
     AbstractResolver,
     CubicalResolver,
-    CoupledAlphaRelativeResolver,
+    PartialSimplicialResolver,
 )
 from homcloud.bitmap import Bitmap
 
@@ -278,7 +278,7 @@ class TestCubicalResolver:
         assert np.allclose(resolver.centroid(cube_index), [0.5, 2.0, 1.0])
 
 
-class TestCoupledAlphaRelativeResolver:
+class TestPartialSimplicialResolver:
     @pytest.fixture
     def resolver(self):
         #  0 - 1
@@ -301,7 +301,7 @@ class TestCoupledAlphaRelativeResolver:
             [1, 2, 3],
             [0, 1, 2, 3],
         ]
-        return CoupledAlphaRelativeResolver(index_to_simplex, vertex_symbols)
+        return PartialSimplicialResolver(index_to_simplex, vertex_symbols)
 
     @pytest.mark.parametrize(
         "index, expected",
