@@ -3,7 +3,7 @@ import numpy as np
 
 from homcloud.maximal_0_component import Graph
 from homcloud.pdgm import PDGM
-from homcloud.alpha_filtration import AlphaShape
+from homcloud.alpha_filtration import AlphaFiltration
 
 
 @pytest.fixture
@@ -17,8 +17,7 @@ def tetrahedron_pdgm(tmpdir):
         ],
         dtype=float,
     )
-    alpha_shape = AlphaShape.build(pointcloud, 3, True, None, None)
-    filt = alpha_shape.create_filtration(True, None, True, False)
+    filt = AlphaFiltration.create(pointcloud, 3, True, None, True, None, True, False)
     path = str(tmpdir.join("tetrahedron.pdgm"))
     with open(path, "wb") as f:
         filt.compute_pdgm(f)
