@@ -4,7 +4,7 @@ import numpy as np
 from homcloud.spatial_searcher import SpatialSearcher
 
 
-class TestSpatialSearcher(object):
+class TestSpatialSearcher:
     @pytest.fixture
     def searcher(self):
         pairs = [(1, 5), (2, 3)]
