@@ -2,7 +2,7 @@ import os
 
 import pytest
 
-from homcloud.view_vectorized_PD import main, argument_parser
+from homcloud.cli.view_vectorized_PD import main, argument_parser
 
 
 @pytest.mark.integration
